Interface: TooltipLabelStyle | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: TooltipLabelStyle

## # Properties

### # backgroundColor

• backgroundColor: `Color`

#### # Defined in

index.esm.d.ts:2448
(opens new window)

### # borderColor

• borderColor: `Color`

#### # Defined in

index.esm.d.ts:2447
(opens new window)

### # borderDash

• `Optional` borderDash: [`number`, `number`]

Border dash

`since` 3.1.0

#### # Defined in

index.esm.d.ts:2460
(opens new window)

### # borderDashOffset

• `Optional` borderDashOffset: `number`

Border dash offset

`since` 3.1.0

#### # Defined in

index.esm.d.ts:2466
(opens new window)

### # borderRadius

• `Optional` borderRadius: `number` | `BorderRadius`

borderRadius

`since` 3.1.0

#### # Defined in

index.esm.d.ts:2472
(opens new window)

### # borderWidth

• `Optional` borderWidth: `number`

Width of border line

`since` 3.1.0

#### # Defined in

index.esm.d.ts:2454
(opens new window)